<?php

namespace Litecms\BoardClient\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litecms\BoardClient\Models\BoardClient;

class BoardClientPolicy
{

    /**
     * Determine if the given user can view the board_client.
     *
     * @param UserPolicy $user
     * @param BoardClient $board_client
     *
     * @return bool
     */
    public function view(UserPolicy $user, BoardClient $board_client)
    {
        if ($user->canDo('board_client.board_client.view') && $user->isAdmin()) {
            return true;
        }

        return $board_client->user_id == user_id() && $board_client->user_type == user_type();
    }

    /**
     * Determine if the given user can create a board_client.
     *
     * @param UserPolicy $user
     * @param BoardClient $board_client
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('board_client.board_client.create');
    }

    /**
     * Determine if the given user can update the given board_client.
     *
     * @param UserPolicy $user
     * @param BoardClient $board_client
     *
     * @return bool
     */
    public function update(UserPolicy $user, BoardClient $board_client)
    {
        if ($user->canDo('board_client.board_client.edit') && $user->isAdmin()) {
            return true;
        }

        return $board_client->user_id == user_id() && $board_client->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given board_client.
     *
     * @param UserPolicy $user
     * @param BoardClient $board_client
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, BoardClient $board_client)
    {
        return $board_client->user_id == user_id() && $board_client->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given board_client.
     *
     * @param UserPolicy $user
     * @param BoardClient $board_client
     *
     * @return bool
     */
    public function verify(UserPolicy $user, BoardClient $board_client)
    {
        if ($user->canDo('board_client.board_client.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given board_client.
     *
     * @param UserPolicy $user
     * @param BoardClient $board_client
     *
     * @return bool
     */
    public function approve(UserPolicy $user, BoardClient $board_client)
    {
        if ($user->canDo('board_client.board_client.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
