<?php

namespace Litecms\BoardClient\Providers;

use Illuminate\Support\ServiceProvider;

class BoardClientServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'board_client');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'board_client');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        // Bind facade
        $this->app->bind('litecms.board_client', function ($app) {
            return $this->app->make('Litecms\BoardClient\BoardClient');
        });

                // Bind BoardClient to repository
        $this->app->bind(
            'Litecms\BoardClient\Interfaces\BoardClientRepositoryInterface',
            \Litecms\BoardClient\Repositories\Eloquent\BoardClientRepository::class
        );

        $this->app->register(\Litecms\BoardClient\Providers\AuthServiceProvider::class);
                $this->app->register(\Litecms\BoardClient\Providers\EventServiceProvider::class);
        
        $this->app->register(\Litecms\BoardClient\Providers\RouteServiceProvider::class);
                
    }

    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['litecms.board_client'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('litecms/board_client.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/board_client')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/board_client')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
